@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -72,7 +72,7 @@
 
 #include "a68g.h"
 
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
 
 #include "a68g-double.h"
 #include "a68g-genie.h"
@@ -98,7 +98,7 @@ void double_G_cfrac_lower (DOUBLE_T * Gcfrac, DOUBLE_T p, DOUBLE_T x)
 // as detailed in the paper, perform manually the first pass (n=1), of the
 // initial Modified Lentz's method.
   DOUBLE_T an = 1.0q, bn = p, del;
-  DOUBLE_T f = an / bn, c = an / A68_DOUBLE_MIN, d = 1.0q / bn;
+  DOUBLE_T f = an / bn, c = an / A68G_DOUBLE_MIN, d = 1.0q / bn;
   INT_T n = 2;
   do {
     INT_T k = n / 2;
@@ -106,18 +106,18 @@ void double_G_cfrac_lower (DOUBLE_T * Gcfrac, DOUBLE_T p, DOUBLE_T x)
     bn++;
     d = an * d + bn;
     if (d == 0.0q) {
-      d = A68_DOUBLE_MIN;
+      d = A68G_DOUBLE_MIN;
     }
     c = bn + an / c;
     if (c == 0.0q) {
-      c = A68_DOUBLE_MIN;
+      c = A68G_DOUBLE_MIN;
     }
     d = 1.0q / d;
     del = d * c;
     f *= del;
     n++;
   }
-  while ((fabs_double (del - 1.0q) >= A68_DOUBLE_EPS) && (n < ITMAX));
+  while ((fabs_double (del - 1.0q) >= A68G_DOUBLE_EPS) && (n < ITMAX));
   *Gcfrac = f;
 }
 
@@ -141,7 +141,7 @@ void double_G_ibp (DOUBLE_T * Gibp, DOUBLE_T p, DOUBLE_T x)
     del = c * (t - d);
     s += del;
     l++;
-    stop = fabs_double (del) < fabs_double (s) * A68_DOUBLE_EPS;
+    stop = fabs_double (del) < fabs_double (s) * A68G_DOUBLE_EPS;
   }
   while ((l < floor_double ((p - 2.0q) / 2.0q)) && !stop);
   if (odd && !stop) {
@@ -184,7 +184,7 @@ void double_G_cfrac_upper (DOUBLE_T * Gcfrac, DOUBLE_T p, DOUBLE_T x)
   if (t) {
 // b{1} is non-zero
     f = an / bn;
-    c = an / A68_DOUBLE_MIN;
+    c = an / A68G_DOUBLE_MIN;
     d = 1.0q / bn;
     n = 2;
   } else {
@@ -192,7 +192,7 @@ void double_G_cfrac_upper (DOUBLE_T * Gcfrac, DOUBLE_T p, DOUBLE_T x)
     an = -(1.0q - p);
     bn = x + 3.0q - p;
     f = an / bn;
-    c = an / A68_DOUBLE_MIN;
+    c = an / A68G_DOUBLE_MIN;
     d = 1.0q / bn;
     n = 3;
   }
@@ -202,11 +202,11 @@ void double_G_cfrac_upper (DOUBLE_T * Gcfrac, DOUBLE_T p, DOUBLE_T x)
     bn += 2.0q;
     d = an * d + bn;
     if (d == 0.0q) {
-      d = A68_DOUBLE_MIN;
+      d = A68G_DOUBLE_MIN;
     }
     c = bn + an / c;
     if (c == 0.0q) {
-      c = A68_DOUBLE_MIN;
+      c = A68G_DOUBLE_MIN;
     }
     d = 1.0q / d;
     del = d * c;
@@ -214,7 +214,7 @@ void double_G_cfrac_upper (DOUBLE_T * Gcfrac, DOUBLE_T p, DOUBLE_T x)
     i++;
     n++;
   }
-  while ((fabs_double (del - 1.0q) >= A68_DOUBLE_EPS) && (n < ITMAX));
+  while ((fabs_double (del - 1.0q) >= A68G_DOUBLE_EPS) && (n < ITMAX));
   *Gcfrac = t ? f : 1.0q / f;
 }
 
@@ -266,7 +266,7 @@ void double_romberg_estimate (DOUBLE_T * rho, DOUBLE_T * sigma, DOUBLE_T x, DOUB
   *sigma = -mu * y + (p - 1.0q) * log_double (y);
   R[0] = 0.5q * (y - x) * (exp_double (-mu * x + (p - 1.0q) * log_double (x) - (*sigma)) + 1.0q);
 // Loop for n > 0
-  DOUBLE_T relneeded = A68_DOUBLE_EPS / TOL_ROMBERG;
+  DOUBLE_T relneeded = A68G_DOUBLE_EPS / TOL_ROMBERG;
   INT_T adr0 = 0;
   INT_T n = 1;
   DOUBLE_T h = (y - x) / 2.0q;       // n=1, h = (y-x)/2^n
@@ -366,26 +366,26 @@ void deltagammainc_double (DOUBLE_T * rho, DOUBLE_T * sigma, DOUBLE_T x, DOUBLE_
 
 void genie_gamma_inc_g_double (NODE_T * n)
 {
-  A68_LONG_REAL x, y, mu, p;
-  POP_OBJECT (n, &mu, A68_LONG_REAL);
-  POP_OBJECT (n, &y, A68_LONG_REAL);
-  POP_OBJECT (n, &x, A68_LONG_REAL);
-  POP_OBJECT (n, &p, A68_LONG_REAL);
+  A68G_LONG_REAL x, y, mu, p;
+  POP_OBJECT (n, &mu, A68G_LONG_REAL);
+  POP_OBJECT (n, &y, A68G_LONG_REAL);
+  POP_OBJECT (n, &x, A68G_LONG_REAL);
+  POP_OBJECT (n, &p, A68G_LONG_REAL);
   DOUBLE_T rho, sigma;
   deltagammainc_double (&rho, &sigma, VALUE (&x).f, VALUE (&y).f, VALUE (&mu).f, VALUE (&p).f);
-  PUSH_VALUE (n, dble (rho * exp_double (sigma)), A68_LONG_REAL);
+  PUSH_VALUE (n, dble (rho * exp_double (sigma)), A68G_LONG_REAL);
 }
 
 //! @brief PROC long gamma inc f = (LONG REAL p, x) LONG REAL
 
 void genie_gamma_inc_f_double (NODE_T * n)
 {
-  A68_LONG_REAL x, p;
-  POP_OBJECT (n, &x, A68_LONG_REAL);
-  POP_OBJECT (n, &p, A68_LONG_REAL);
+  A68G_LONG_REAL x, p;
+  POP_OBJECT (n, &x, A68G_LONG_REAL);
+  POP_OBJECT (n, &p, A68G_LONG_REAL);
   DOUBLE_T rho, sigma;
   deltagammainc_double (&rho, &sigma, VALUE (&x).f, a68g_posinf_double (), 1.0q, VALUE (&p).f);
-  PUSH_VALUE (n, dble (rho * exp_double (sigma)), A68_LONG_REAL);
+  PUSH_VALUE (n, dble (rho * exp_double (sigma)), A68G_LONG_REAL);
 }
 
 //! @brief PROC long gamma inc gf = (LONG REAL p, x) LONG REAL
@@ -394,19 +394,19 @@ void genie_gamma_inc_gf_double (NODE_T * q)
 {
 // if x <= p: G(p,x) = exp (x-p*ln (|x|)) * integral over [0,|x|] of s^{p-1} * exp (-sign (x)*s) ds
 // otherwise: G(p,x) = exp (x-p*ln (x)) * integral over [x,inf] of s^{p-1} * exp (-s) ds
-  A68_LONG_REAL x, p;
-  POP_OBJECT (q, &x, A68_LONG_REAL);
-  POP_OBJECT (q, &p, A68_LONG_REAL);
+  A68G_LONG_REAL x, p;
+  POP_OBJECT (q, &x, A68G_LONG_REAL);
+  POP_OBJECT (q, &p, A68G_LONG_REAL);
   DOUBLE_T G;
   double_G_func (&G, VALUE (&p).f, VALUE (&x).f);
-  PUSH_VALUE (q, dble (G), A68_LONG_REAL);
+  PUSH_VALUE (q, dble (G), A68G_LONG_REAL);
 }
 
 //! @brief PROC long gamma inc = (LONG REAL p, x) LONG REAL
 
 void genie_gamma_inc_h_double (NODE_T * n)
 {
-#if (A68_LEVEL >= 3) && defined (HAVE_GNU_MPFR)
+#if (A68G_LEVEL >= 3) && defined (HAVE_GNU_MPFR)
   genie_gamma_inc_double_mpfr (n);
 #else
   genie_gamma_inc_f_double (n);
