@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -97,7 +97,7 @@ PROP_T genie_assignation_quick (NODE_T * p)
   NODE_T *dst = SUB (p);
   NODE_T *src = NEXT_NEXT (dst);
   MOID_T *src_mode = SUB_MOID (dst);
-  int size = SIZE (src_mode);
+  size_t size = SIZE (src_mode);
   ADDR_T pop_fp = FRAME_DNS (A68G_FP);
   A68G_REF *z = (A68G_REF *) STACK_TOP;
   GENIE_UNIT (dst);
@@ -126,7 +126,7 @@ PROP_T genie_assignation (NODE_T * p)
   NODE_T *dst = SUB (p);
   NODE_T *src = NEXT_NEXT (dst);
   MOID_T *src_mode = SUB_MOID (dst);
-  int size = SIZE (src_mode);
+  size_t size = SIZE (src_mode);
   ADDR_T pop_fp = FRAME_DNS (A68G_FP);
   A68G_REF *z = (A68G_REF *) STACK_TOP;
   GENIE_UNIT (dst);
