@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -412,7 +412,7 @@ void genie (void *compile_plugin)
     A68G (in_execution) = A68G_TRUE;
     A68G (f_entry) = TOP_NODE (&A68G_JOB);
     #if defined (BUILD_UNIX)
-      (void) a68g_alarm (INTERRUPT_INTERVAL);
+      (void) a68g_alarm (A68G_SIGALRM_INTERVAL);
     #endif
     if (OPTION_TRACE (&A68G_JOB)) {
       WIS (TOP_NODE (&A68G_JOB));
