@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -36,10 +36,10 @@ void absorb_series_pack (MOID_T ** p)
   BOOL_T siga;
   do {
     PACK_T *z = NO_PACK;
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     for (PACK_T *t = PACK (*p); t != NO_PACK; FORWARD (t)) {
       if (MOID (t) != NO_MOID && IS (MOID (t), SERIES_MODE)) {
-        siga = A68_TRUE;
+        siga = A68G_TRUE;
         for (PACK_T *s = PACK (MOID (t)); s != NO_PACK; FORWARD (s)) {
           add_mode_to_pack (&z, MOID (s), NO_TEXT, NODE (s));
         }
@@ -61,7 +61,7 @@ MOID_T *make_series_from_moids (MOID_T * u, MOID_T * v)
   add_mode_to_pack (&(PACK (x)), v, NO_TEXT, NODE (v));
   absorb_series_pack (&x);
   DIM (x) = count_pack_members (PACK (x));
-  (void) register_extra_mode (&TOP_MOID (&A68_JOB), x);
+  (void) register_extra_mode (&TOP_MOID (&A68G_JOB), x);
   if (DIM (x) == 1) {
     return MOID (PACK (x));
   } else {
@@ -78,7 +78,7 @@ MOID_T *absorb_related_subsets (MOID_T * m)
   BOOL_T siga;
   do {
     PACK_T *u = NO_PACK;
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     for (PACK_T *v = PACK (m); v != NO_PACK; FORWARD (v)) {
       MOID_T *n = depref_completely (MOID (v));
       if (IS (n, UNION_SYMBOL) && is_subset (n, m, SAFE_DEFLEXING)) {
@@ -86,7 +86,7 @@ MOID_T *absorb_related_subsets (MOID_T * m)
         for (PACK_T *w = PACK (n); w != NO_PACK; FORWARD (w)) {
           add_mode_to_pack (&u, MOID (w), NO_TEXT, NODE (w));
         }
-        siga = A68_TRUE;
+        siga = A68G_TRUE;
       } else {
         add_mode_to_pack (&u, MOID (v), NO_TEXT, NODE (v));
       }
@@ -103,10 +103,10 @@ void absorb_series_union_pack (MOID_T ** p)
   BOOL_T siga;
   do {
     PACK_T *z = NO_PACK;
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     for (PACK_T *t = PACK (*p); t != NO_PACK; FORWARD (t)) {
       if (MOID (t) != NO_MOID && (IS (MOID (t), SERIES_MODE) || IS (MOID (t), UNION_SYMBOL))) {
-        siga = A68_TRUE;
+        siga = A68G_TRUE;
         for (PACK_T *s = PACK (MOID (t)); s != NO_PACK; FORWARD (s)) {
           add_mode_to_pack (&z, MOID (s), NO_TEXT, NODE (s));
         }
@@ -150,7 +150,7 @@ MOID_T *make_united_mode (MOID_T * m)
   if (DIM (u) == 1) {
     return MOID (PACK (u));
   } else {
-    return register_extra_mode (&TOP_MOID (&A68_JOB), u);
+    return register_extra_mode (&TOP_MOID (&A68G_JOB), u);
   }
 }
 
@@ -161,7 +161,7 @@ void make_soid (SOID_T * s, int sort, MOID_T * type, int attribute)
   ATTRIBUTE (s) = attribute;
   SORT (s) = sort;
   MOID (s) = type;
-  CAST (s) = A68_FALSE;
+  CAST (s) = A68G_FALSE;
 }
 
 //! @brief Whether mode is not well defined.
@@ -169,17 +169,17 @@ void make_soid (SOID_T * s, int sort, MOID_T * type, int attribute)
 BOOL_T is_mode_isnt_well (MOID_T * p)
 {
   if (p == NO_MOID) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (!IF_MODE_IS_WELL (p)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (PACK (p) != NO_PACK) {
     for (PACK_T *q = PACK (p); q != NO_PACK; FORWARD (q)) {
       if (!IF_MODE_IS_WELL (MOID (q))) {
-        return A68_TRUE;
+        return A68G_TRUE;
       }
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Add SOID data to free chain.
@@ -191,8 +191,8 @@ void free_soid_list (SOID_T * root)
     for (; NEXT (q) != NO_SOID; FORWARD (q)) {
       ;
     }
-    NEXT (q) = A68 (top_soid_list);
-    A68 (top_soid_list) = root;
+    NEXT (q) = A68G (top_soid_list);
+    A68G (top_soid_list) = root;
   }
 }
 
@@ -204,11 +204,11 @@ void add_to_soid_list (SOID_T ** root, NODE_T * where, SOID_T * soid)
     add_to_soid_list (&(NEXT (*root)), where, soid);
   } else {
     SOID_T *new_one;
-    if (A68 (top_soid_list) == NO_SOID) {
+    if (A68G (top_soid_list) == NO_SOID) {
       new_one = (SOID_T *) get_temp_heap_space ((size_t) SIZE_ALIGNED (SOID_T));
     } else {
-      new_one = A68 (top_soid_list);
-      FORWARD (A68 (top_soid_list));
+      new_one = A68G (top_soid_list);
+      FORWARD (A68G (top_soid_list));
     }
     make_soid (new_one, SORT (soid), MOID (soid), 0);
     NODE (new_one) = where;
@@ -243,7 +243,7 @@ MOID_T *pack_soids_in_moid (SOID_T * top_sl, int attribute)
     *p = t;
     p = &NEXT (t);
   }
-  (void) register_extra_mode (&TOP_MOID (&A68_JOB), x);
+  (void) register_extra_mode (&TOP_MOID (&A68G_JOB), x);
   return x;
 }
 
@@ -272,7 +272,7 @@ BOOL_T is_equal_modes (MOID_T * p, MOID_T * q, int deflex)
 BOOL_T is_deprefable (MOID_T * p)
 {
   if (IS_REF (p)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
     return (BOOL_T) (IS (p, PROC_SYMBOL) && PACK (p) == NO_PACK);
   }
@@ -345,11 +345,11 @@ BOOL_T is_rows_type (MOID_T * p)
   switch (ATTRIBUTE (p)) {
   case ROW_SYMBOL:
   case FLEX_SYMBOL: {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   case UNION_SYMBOL: {
       PACK_T *t = PACK (p);
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       while (t != NO_PACK && siga) {
         siga &= is_rows_type (MOID (t));
         FORWARD (t);
@@ -357,7 +357,7 @@ BOOL_T is_rows_type (MOID_T * p)
       return siga;
     }
   default: {
-      return A68_FALSE;
+      return A68G_FALSE;
     }
   }
 }
@@ -367,11 +367,11 @@ BOOL_T is_rows_type (MOID_T * p)
 BOOL_T is_proc_ref_file_void_or_format (const MOID_T * p)
 {
   if (p == M_PROC_REF_FILE_VOID) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_FORMAT) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -380,56 +380,56 @@ BOOL_T is_proc_ref_file_void_or_format (const MOID_T * p)
 BOOL_T is_transput_mode (MOID_T * p, char rw)
 {
   if (p == M_INT) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_LONG_INT) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_LONG_LONG_INT) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_REAL) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_LONG_REAL) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_LONG_LONG_REAL) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_BOOL) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_CHAR) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_BITS) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_LONG_BITS) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_LONG_LONG_BITS) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_COMPLEX) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_LONG_COMPLEX) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_LONG_LONG_COMPLEX) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_ROW_CHAR) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_STRING) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_SOUND) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (p, UNION_SYMBOL) || IS (p, STRUCT_SYMBOL)) {
     for (PACK_T *q = PACK (p); q != NO_PACK; FORWARD (q)) {
       if (! (is_transput_mode (MOID (q), rw) || is_proc_ref_file_void_or_format (MOID (q)))) {
-        return A68_FALSE;
+        return A68G_FALSE;
       }
     }
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS_FLEX (p)) {
     if (SUB (p) == M_ROW_CHAR) {
-      return A68_TRUE;
+      return A68G_TRUE;
     } else {
-      return (BOOL_T) (rw == 'w' ? is_transput_mode (SUB (p), rw) : A68_FALSE);
+      return (BOOL_T) (rw == 'w' ? is_transput_mode (SUB (p), rw) : A68G_FALSE);
     }
   } else if (IS_ROW (p)) {
     return (BOOL_T) (is_transput_mode (SUB (p), rw) || is_proc_ref_file_void_or_format (SUB (p)));
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -438,7 +438,7 @@ BOOL_T is_transput_mode (MOID_T * p, char rw)
 BOOL_T is_printable_mode (MOID_T * p)
 {
   if (is_proc_ref_file_void_or_format (p)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
     return is_transput_mode (p, 'w');
   }
@@ -449,20 +449,20 @@ BOOL_T is_printable_mode (MOID_T * p)
 BOOL_T is_readable_mode (MOID_T * p)
 {
   if (is_proc_ref_file_void_or_format (p)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS_REF (p)) {
     return is_transput_mode (SUB (p), 'r');
   } else if (IS_UNION (p)) { 
     for (PACK_T *q = PACK (p); q != NO_PACK; FORWARD (q)) {
       if (!IS_REF (MOID (q))) {
-        return A68_FALSE;
+        return A68G_FALSE;
       } else if (!is_transput_mode (SUB (MOID (q)), 'r')) {
-        return A68_FALSE;
+        return A68G_FALSE;
       }
     }
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -470,7 +470,7 @@ BOOL_T is_readable_mode (MOID_T * p)
 
 BOOL_T is_name_struct (MOID_T * p)
 {
-  return (BOOL_T) (NAME (p) != NO_MOID ? IS (DEFLEX (SUB (p)), STRUCT_SYMBOL) : A68_FALSE);
+  return (BOOL_T) (NAME (p) != NO_MOID ? IS (DEFLEX (SUB (p)), STRUCT_SYMBOL) : A68G_FALSE);
 }
 
 //! @brief Yield mode to unite to.
@@ -499,17 +499,17 @@ BOOL_T is_moid_in_pack (MOID_T * u, PACK_T * v, int deflex)
 {
   for (; v != NO_PACK; FORWARD (v)) {
     if (is_equal_modes (u, MOID (v), deflex)) {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Whether "p" is a subset of "q".
 
 BOOL_T is_subset (MOID_T * p, MOID_T * q, int deflex)
 {
-  BOOL_T j = A68_TRUE;
+  BOOL_T j = A68G_TRUE;
   for (PACK_T *u = PACK (p); u != NO_PACK && j; FORWARD (u)) {
     j = (BOOL_T) (j && is_moid_in_pack (MOID (u), PACK (q), deflex));
   }
@@ -527,17 +527,17 @@ BOOL_T is_unitable (MOID_T * p, MOID_T * q, int deflex)
       return is_moid_in_pack (p, PACK (q), deflex);
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief Whether all or some components of "u" can be firmly coerced to a component mode of "v"..
 
 void investigate_firm_relations (PACK_T * u, PACK_T * v, BOOL_T * all, BOOL_T * some)
 {
-  *all = A68_TRUE;
-  *some = A68_FALSE;
+  *all = A68G_TRUE;
+  *some = A68G_FALSE;
   for (; v != NO_PACK; FORWARD (v)) {
-    BOOL_T k = A68_FALSE;
+    BOOL_T k = A68G_FALSE;
     for (PACK_T *w = u; w != NO_PACK; FORWARD (w)) {
       k |= is_coercible (MOID (w), MOID (v), FIRM, FORCE_DEFLEXING);
     }
@@ -551,11 +551,11 @@ void investigate_firm_relations (PACK_T * u, PACK_T * v, BOOL_T * all, BOOL_T *
 BOOL_T is_softly_coercible (MOID_T * p, MOID_T * q, int deflex)
 {
   if (is_equal_modes (p, q, deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (p, PROC_SYMBOL) && PACK (p) == NO_PACK) {
     return is_softly_coercible (SUB (p), q, deflex);
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -564,11 +564,11 @@ BOOL_T is_softly_coercible (MOID_T * p, MOID_T * q, int deflex)
 BOOL_T is_weakly_coercible (MOID_T * p, MOID_T * q, int deflex)
 {
   if (is_equal_modes (p, q, deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_deprefable (p)) {
     return is_weakly_coercible (depref_once (p), q, deflex);
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -577,11 +577,11 @@ BOOL_T is_weakly_coercible (MOID_T * p, MOID_T * q, int deflex)
 BOOL_T is_meekly_coercible (MOID_T * p, MOID_T * q, int deflex)
 {
   if (is_equal_modes (p, q, deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_deprefable (p)) {
     return is_meekly_coercible (depref_once (p), q, deflex);
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -590,15 +590,15 @@ BOOL_T is_meekly_coercible (MOID_T * p, MOID_T * q, int deflex)
 BOOL_T is_firmly_coercible (MOID_T * p, MOID_T * q, int deflex)
 {
   if (is_equal_modes (p, q, deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (q == M_ROWS && is_rows_type (p)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_unitable (p, q, deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_deprefable (p)) {
     return is_firmly_coercible (depref_once (p), q, deflex);
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -716,9 +716,9 @@ BOOL_T is_widenable (MOID_T * p, MOID_T * q)
 {
   MOID_T *z = widens_to (p, q);
   if (z != NO_MOID) {
-    return (BOOL_T) (z == q ? A68_TRUE : is_widenable (z, q));
+    return (BOOL_T) (z == q ? A68G_TRUE : is_widenable (z, q));
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -726,7 +726,7 @@ BOOL_T is_widenable (MOID_T * p, MOID_T * q)
 
 BOOL_T is_ref_row (MOID_T * p)
 {
-  return (BOOL_T) (NAME (p) != NO_MOID ? IS_ROW (DEFLEX (SUB (p))) : A68_FALSE);
+  return (BOOL_T) (NAME (p) != NO_MOID ? IS_ROW (DEFLEX (SUB (p))) : A68G_FALSE);
 }
 
 //! @brief Whether strong name.
@@ -734,11 +734,11 @@ BOOL_T is_ref_row (MOID_T * p)
 BOOL_T is_strong_name (MOID_T * p, MOID_T * q)
 {
   if (p == q) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_ref_row (q)) {
     return is_strong_name (p, NAME (q));
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -747,7 +747,7 @@ BOOL_T is_strong_name (MOID_T * p, MOID_T * q)
 BOOL_T is_strong_slice (MOID_T * p, MOID_T * q)
 {
   if (p == q || is_widenable (p, q)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (SLICE (q) != NO_MOID) {
     return is_strong_slice (p, SLICE (q));
   } else if (IS_FLEX (q)) {
@@ -755,7 +755,7 @@ BOOL_T is_strong_slice (MOID_T * p, MOID_T * q)
   } else if (is_ref_row (q)) {
     return is_strong_name (p, q);
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -765,30 +765,30 @@ BOOL_T is_strongly_coercible (MOID_T * p, MOID_T * q, int deflex)
 {
 // Keep this sequence of statements.
   if (is_equal_modes (p, q, deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (q == M_VOID) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if ((q == M_SIMPLIN || q == M_ROW_SIMPLIN) && is_readable_mode (p)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (q == M_ROWS && is_rows_type (p)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_unitable (p, derow (q), deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   }
   if (is_ref_row (q) && is_strong_name (p, q)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (SLICE (q) != NO_MOID && is_strong_slice (p, q)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS_FLEX (q) && is_strong_slice (p, q)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_widenable (p, q)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_deprefable (p)) {
     return is_strongly_coercible (depref_once (p), q, deflex);
   } else if (q == M_SIMPLOUT || q == M_ROW_SIMPLOUT) {
     return is_printable_mode (p);
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -797,7 +797,7 @@ BOOL_T is_strongly_coercible (MOID_T * p, MOID_T * q, int deflex)
 BOOL_T basic_coercions (MOID_T * p, MOID_T * q, int c, int deflex)
 {
   if (is_equal_modes (p, q, deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (c == NO_SORT) {
     return (BOOL_T) (p == q);
   } else if (c == SOFT) {
@@ -811,7 +811,7 @@ BOOL_T basic_coercions (MOID_T * p, MOID_T * q, int c, int deflex)
   } else if (c == STRONG) {
     return is_strongly_coercible (p, q, deflex);
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -821,27 +821,27 @@ BOOL_T is_coercible_stowed (MOID_T * p, MOID_T * q, int c, int deflex)
 {
   if (c != STRONG) {
 // Such construct is always in a strong position, is it not?
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (q == M_VOID) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS_FLEX (q)) {
-    BOOL_T j = A68_TRUE;
+    BOOL_T j = A68G_TRUE;
     for (PACK_T *u = PACK (p); u != NO_PACK && j; FORWARD (u)) {
       j &= is_coercible (MOID (u), SLICE (SUB (q)), c, deflex);
     }
     return j;
   } else if (IS_ROW (q)) {
-    BOOL_T j = A68_TRUE;
+    BOOL_T j = A68G_TRUE;
     for (PACK_T *u = PACK (p); u != NO_PACK && j; FORWARD (u)) {
       j &= is_coercible (MOID (u), SLICE (q), c, deflex);
     }
     return j;
   } else if (IS (q, PROC_SYMBOL) || IS (q, STRUCT_SYMBOL)) {
     if (DIM (p) != DIM (q)) {
-      return A68_FALSE;
+      return A68G_FALSE;
     } else {
       PACK_T *u = PACK (p), *v = PACK (q);
-      BOOL_T j = A68_TRUE;
+      BOOL_T j = A68G_TRUE;
       while (u != NO_PACK && v != NO_PACK && j) {
         j &= is_coercible (MOID (u), MOID (v), c, deflex);
         FORWARD (u);
@@ -850,7 +850,7 @@ BOOL_T is_coercible_stowed (MOID_T * p, MOID_T * q, int c, int deflex)
       return j;
     }
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -859,17 +859,17 @@ BOOL_T is_coercible_stowed (MOID_T * p, MOID_T * q, int c, int deflex)
 BOOL_T is_coercible_series (MOID_T * p, MOID_T * q, int c, int deflex)
 {
   if (c == NO_SORT) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (p == NO_MOID || q == NO_MOID) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (IS (p, SERIES_MODE) && PACK (p) == NO_PACK) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (IS (q, SERIES_MODE) && PACK (q) == NO_PACK) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (PACK (p) == NO_PACK) {
     return is_coercible (p, q, c, deflex);
   } else {
-    BOOL_T j = A68_TRUE;
+    BOOL_T j = A68G_TRUE;
     for (PACK_T *u = PACK (p); u != NO_PACK && j; FORWARD (u)) {
       if (MOID (u) != NO_MOID) {
         j &= is_coercible (MOID (u), q, c, deflex);
@@ -884,17 +884,17 @@ BOOL_T is_coercible_series (MOID_T * p, MOID_T * q, int c, int deflex)
 BOOL_T is_coercible (MOID_T * p, MOID_T * q, int c, int deflex)
 {
   if (is_mode_isnt_well (p) || is_mode_isnt_well (q)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_equal_modes (p, q, deflex)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (p == M_HIP) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (p, STOWED_MODE)) {
     return is_coercible_stowed (p, q, c, deflex);
   } else if (IS (p, SERIES_MODE)) {
     return is_coercible_series (p, q, c, deflex);
   } else if (p == M_VACUUM && IS_ROW (DEFLEX (q))) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
     return basic_coercions (p, q, c, deflex);
   }
@@ -905,9 +905,9 @@ BOOL_T is_coercible (MOID_T * p, MOID_T * q, int c, int deflex)
 BOOL_T is_coercible_in_context (SOID_T * p, SOID_T * q, int deflex)
 {
   if (SORT (p) != SORT (q)) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (MOID (p) == MOID (q)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
     return is_coercible (MOID (p), MOID (q), SORT (q), deflex);
   }
@@ -918,14 +918,14 @@ BOOL_T is_coercible_in_context (SOID_T * p, SOID_T * q, int deflex)
 BOOL_T is_balanced (NODE_T * n, SOID_T * y, int sort)
 {
   if (sort == STRONG) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
-    BOOL_T k = A68_FALSE;
+    BOOL_T k = A68G_FALSE;
     for (; y != NO_SOID && !k; FORWARD (y)) {
       k = (BOOL_T) (!IS (MOID (y), STOWED_MODE));
     }
-    if (k == A68_FALSE) {
-      diagnostic (A68_ERROR, n, ERROR_NO_UNIQUE_MODE);
+    if (k == A68G_FALSE) {
+      diagnostic (A68G_ERROR, n, ERROR_NO_UNIQUE_MODE);
     }
     return k;
   }
@@ -938,10 +938,10 @@ MOID_T *get_balanced_mode (MOID_T * m, int sort, BOOL_T return_depreffed, int de
   MOID_T *common_moid = NO_MOID;
   if (m != NO_MOID && !is_mode_isnt_well (m) && IS (m, UNION_SYMBOL)) {
     int depref_level;
-    BOOL_T siga = A68_TRUE;
+    BOOL_T siga = A68G_TRUE;
 // Test for increasing depreffing.
     for (depref_level = 0; siga; depref_level++) {
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
 // Test the whole pack.
       for (PACK_T *p = PACK (m); p != NO_PACK; FORWARD (p)) {
 // HIPs are not eligible of course.
@@ -955,8 +955,8 @@ MOID_T *get_balanced_mode (MOID_T * m, int sort, BOOL_T return_depreffed, int de
 // Only need testing if all allowed deprefs succeeded.
           if (k == 0) {
             MOID_T *to = (return_depreffed ? depref_completely (candidate) : candidate);
-            BOOL_T all_coercible = A68_TRUE;
-            siga = A68_TRUE;
+            BOOL_T all_coercible = A68G_TRUE;
+            siga = A68G_TRUE;
             for (PACK_T *q = PACK (m); q != NO_PACK && all_coercible; FORWARD (q)) {
               MOID_T *from = MOID (q);
               if (p != q && from != to) {
@@ -992,10 +992,10 @@ BOOL_T clause_allows_balancing (int att)
   case CASE_CLAUSE:
   case SERIAL_CLAUSE:
   case CONFORMITY_CLAUSE: {
-      return A68_TRUE;
+      return A68G_TRUE;
     }
   }
-  return A68_FALSE;
+  return A68G_FALSE;
 }
 
 //! @brief A unique mode from "z".
@@ -1126,11 +1126,11 @@ void make_depreffing_coercion (NODE_T * n, MOID_T * p, MOID_T * q)
 BOOL_T is_nonproc (MOID_T * p)
 {
   if (IS (p, PROC_SYMBOL) && PACK (p) == NO_PACK) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (IS_REF (p)) {
     return is_nonproc (SUB (p));
   } else {
-    return A68_TRUE;
+    return A68G_TRUE;
   }
 }
 
