@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -30,7 +30,7 @@
 
 MP_T *cmul_mp (NODE_T * p, MP_T * a, MP_T * b, MP_T * c, MP_T * d, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *la = len_mp (p, a, digs, gdigs), *lb = len_mp (p, b, digs, gdigs);
   MP_T *lc = len_mp (p, c, digs, gdigs), *ld = len_mp (p, d, digs, gdigs);
@@ -44,7 +44,7 @@ MP_T *cmul_mp (NODE_T * p, MP_T * a, MP_T * b, MP_T * c, MP_T * d, int digs)
   (void) add_mp (p, lb, ad, bc, gdigs);
   (void) shorten_mp (p, a, digs, la, gdigs);
   (void) shorten_mp (p, b, digs, lb, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return a;
 }
 
@@ -52,7 +52,7 @@ MP_T *cmul_mp (NODE_T * p, MP_T * a, MP_T * b, MP_T * c, MP_T * d, int digs)
 
 MP_T *cdiv_mp (NODE_T * p, MP_T * a, MP_T * b, MP_T * c, MP_T * d, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   if (MP_DIGIT (c, 1) == (MP_T) 0 && MP_DIGIT (d, 1) == (MP_T) 0) {
     errno = ERANGE;
     return NaN_MP;
@@ -92,7 +92,7 @@ MP_T *cdiv_mp (NODE_T * p, MP_T * a, MP_T * b, MP_T * c, MP_T * d, int digs)
   }
   (void) move_mp (a, c, digs);
   (void) move_mp (b, d, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return a;
 }
 
@@ -100,7 +100,7 @@ MP_T *cdiv_mp (NODE_T * p, MP_T * a, MP_T * b, MP_T * c, MP_T * d, int digs)
 
 MP_T *csqrt_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   if (IS_ZERO_MP (re) && IS_ZERO_MP (im)) {
@@ -152,7 +152,7 @@ MP_T *csqrt_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   }
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -160,7 +160,7 @@ MP_T *csqrt_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *cexp_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   if (IS_ZERO_MP (im)) {
@@ -175,7 +175,7 @@ MP_T *cexp_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   }
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -183,7 +183,7 @@ MP_T *cexp_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *cln_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *s = nil_mp (p, gdigs), *t = nil_mp (p, gdigs);
@@ -198,7 +198,7 @@ MP_T *cln_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   (void) move_mp (im, t, gdigs);
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -206,7 +206,7 @@ MP_T *cln_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *csin_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *s = nil_mp (p, gdigs), *c = nil_mp (p, gdigs);
@@ -223,7 +223,7 @@ MP_T *csin_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   }
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -231,7 +231,7 @@ MP_T *csin_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *ccos_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *s = nil_mp (p, gdigs), *c = nil_mp (p, gdigs);
@@ -249,7 +249,7 @@ MP_T *ccos_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   }
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -257,7 +257,7 @@ MP_T *ccos_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *ctan_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   errno = 0;
   MP_T *s = nil_mp (p, digs), *t = nil_mp (p, digs);
   MP_T *u = nil_mp (p, digs), *v = nil_mp (p, digs);
@@ -272,7 +272,7 @@ MP_T *ctan_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   (void) cdiv_mp (p, s, t, u, v, digs);
   (void) move_mp (r, s, digs);
   (void) move_mp (i, t, digs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -281,7 +281,7 @@ MP_T *ctan_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 MP_T *casin_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
 // asin(z) = -i log(i z + sqrt(1 - z*z))
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   BOOL_T negim = MP_DIGIT (im, 1) < 0;
@@ -310,7 +310,7 @@ MP_T *casin_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   }
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return re;
 }
 
@@ -319,7 +319,7 @@ MP_T *casin_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 MP_T *cacos_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
 // acos (z) = pi/2 - asin (z)
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   BOOL_T negim = MP_DIGIT (im, 1) < 0;
@@ -348,7 +348,7 @@ MP_T *cacos_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   }
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return re;
 }
 
@@ -357,7 +357,7 @@ MP_T *cacos_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 MP_T *catan_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
 // arctan (z) = -i aractanh (iz).
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *u = nil_mp (p, gdigs), *v = nil_mp (p, gdigs);
@@ -401,7 +401,7 @@ MP_T *catan_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   }
   (void) shorten_mp (p, r, digs, u, gdigs);
   (void) shorten_mp (p, i, digs, v, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return re;
 }
 
@@ -409,7 +409,7 @@ MP_T *catan_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *csinh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *u = nil_mp (p, gdigs), *v = nil_mp (p, gdigs);
@@ -422,7 +422,7 @@ MP_T *csinh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   (void) cmul_mp (p, re, im, u, v, gdigs);
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -430,7 +430,7 @@ MP_T *csinh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *ccosh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *u = nil_mp (p, gdigs), *v = nil_mp (p, gdigs);
@@ -441,7 +441,7 @@ MP_T *ccosh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   (void) ccos_mp (p, re, im, gdigs);
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -449,7 +449,7 @@ MP_T *ccosh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *ctanh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *u = nil_mp (p, gdigs), *v = nil_mp (p, gdigs);
@@ -462,7 +462,7 @@ MP_T *ctanh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   (void) cmul_mp (p, re, im, u, v, gdigs);
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -470,7 +470,7 @@ MP_T *ctanh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *casinh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *u = nil_mp (p, gdigs), *v = nil_mp (p, gdigs);
@@ -483,7 +483,7 @@ MP_T *casinh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   (void) cmul_mp (p, re, im, u, v, gdigs);
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -491,7 +491,7 @@ MP_T *casinh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *cacosh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *u = nil_mp (p, gdigs), *v = nil_mp (p, gdigs);
@@ -502,7 +502,7 @@ MP_T *cacosh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   (void) cmul_mp (p, re, im, u, v, gdigs);
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
 
@@ -510,7 +510,7 @@ MP_T *cacosh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 
 MP_T *catanh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
 {
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int gdigs = FUN_DIGITS (digs);
   MP_T *re = len_mp (p, r, digs, gdigs), *im = len_mp (p, i, digs, gdigs);
   MP_T *u = nil_mp (p, gdigs), *v = nil_mp (p, gdigs);
@@ -523,6 +523,6 @@ MP_T *catanh_mp (NODE_T * p, MP_T * r, MP_T * i, int digs)
   (void) cmul_mp (p, re, im, u, v, gdigs);
   (void) shorten_mp (p, r, digs, re, gdigs);
   (void) shorten_mp (p, i, digs, im, gdigs);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   return r;
 }
