@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -33,7 +33,7 @@ BOOL_T victal_check_declarer (NODE_T *, int);
 void victal_check_generator (NODE_T * p)
 {
   if (!victal_check_declarer (NEXT (p), ACTUAL_DECLARER_MARK)) {
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "actual declarer");
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "actual declarer");
   }
 }
 
@@ -61,15 +61,15 @@ void victal_check_formal_pack (NODE_T * p, int x, BOOL_T * z)
 void victal_check_operator_dec (NODE_T * p)
 {
   if (IS (NEXT (p), FORMAL_DECLARERS)) {
-    BOOL_T z = A68_TRUE;
+    BOOL_T z = A68G_TRUE;
     victal_check_formal_pack (NEXT (p), FORMAL_DECLARER_MARK, &z);
     if (!z) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarers");
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarers");
     }
     FORWARD (p);
   }
   if (!victal_check_declarer (NEXT (p), FORMAL_DECLARER_MARK)) {
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
   }
 }
 
@@ -86,7 +86,7 @@ void victal_check_mode_dec (NODE_T * p)
       victal_check_mode_dec (NEXT (p));
     } else if (IS (p, DECLARER)) {
       if (!victal_check_declarer (p, ACTUAL_DECLARER_MARK)) {
-        diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "actual declarer");
+        diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "actual declarer");
       }
     }
   }
@@ -108,7 +108,7 @@ void victal_check_variable_dec (NODE_T * p)
       victal_check_variable_dec (NEXT (p));
     } else if (IS (p, DECLARER)) {
       if (!victal_check_declarer (p, ACTUAL_DECLARER_MARK)) {
-        diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "actual declarer");
+        diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "actual declarer");
       }
       victal_check_variable_dec (NEXT (p));
     }
@@ -129,7 +129,7 @@ void victal_check_identity_dec (NODE_T * p)
       victal_checker (SUB (p));
     } else if (IS (p, DECLARER)) {
       if (!victal_check_declarer (p, FORMAL_DECLARER_MARK)) {
-        diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
+        diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
       }
       victal_check_identity_dec (NEXT (p));
     }
@@ -159,15 +159,15 @@ void victal_check_routine_pack (NODE_T * p, int x, BOOL_T * z)
 void victal_check_routine_text (NODE_T * p)
 {
   if (IS (p, PARAMETER_PACK)) {
-    BOOL_T z = A68_TRUE;
+    BOOL_T z = A68G_TRUE;
     victal_check_routine_pack (p, FORMAL_DECLARER_MARK, &z);
     if (!z) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarers");
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarers");
     }
     FORWARD (p);
   }
   if (!victal_check_declarer (p, FORMAL_DECLARER_MARK)) {
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
   }
   victal_checker (NEXT (p));
 }
@@ -214,13 +214,13 @@ void victal_check_union_pack (NODE_T * p, int x, BOOL_T * z)
 BOOL_T victal_check_declarer (NODE_T * p, int x)
 {
   if (p == NO_NODE) {
-    return A68_FALSE;
+    return A68G_FALSE;
   } else if (IS (p, DECLARER)) {
     return victal_check_declarer (SUB (p), x);
   } else if (is_one_of (p, LONGETY, SHORTETY, STOP)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (is_one_of (p, VOID_SYMBOL, INDICANT, STANDARD, STOP)) {
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS_REF (p)) {
     return victal_check_declarer (NEXT (p), VIRTUAL_DECLARER_MARK);
   } else if (IS_FLEX (p)) {
@@ -228,51 +228,51 @@ BOOL_T victal_check_declarer (NODE_T * p, int x)
   } else if (IS (p, BOUNDS)) {
     victal_checker (SUB (p));
     if (x == FORMAL_DECLARER_MARK) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal bounds");
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal bounds");
       (void) victal_check_declarer (NEXT (p), x);
-      return A68_TRUE;
+      return A68G_TRUE;
     } else if (x == VIRTUAL_DECLARER_MARK) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "virtual bounds");
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "virtual bounds");
       (void) victal_check_declarer (NEXT (p), x);
-      return A68_TRUE;
+      return A68G_TRUE;
     } else {
       return victal_check_declarer (NEXT (p), x);
     }
   } else if (IS (p, FORMAL_BOUNDS)) {
     victal_checker (SUB (p));
     if (x == ACTUAL_DECLARER_MARK) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "actual bounds");
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "actual bounds");
       (void) victal_check_declarer (NEXT (p), x);
-      return A68_TRUE;
+      return A68G_TRUE;
     } else {
       return victal_check_declarer (NEXT (p), x);
     }
   } else if (IS (p, STRUCT_SYMBOL)) {
-    BOOL_T z = A68_TRUE;
+    BOOL_T z = A68G_TRUE;
     victal_check_structure_pack (NEXT (p), x, &z);
     return z;
   } else if (IS (p, UNION_SYMBOL)) {
-    BOOL_T z = A68_TRUE;
+    BOOL_T z = A68G_TRUE;
     victal_check_union_pack (NEXT (p), FORMAL_DECLARER_MARK, &z);
     if (!z) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer pack");
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer pack");
     }
-    return A68_TRUE;
+    return A68G_TRUE;
   } else if (IS (p, PROC_SYMBOL)) {
     if (IS (NEXT (p), FORMAL_DECLARERS)) {
-      BOOL_T z = A68_TRUE;
+      BOOL_T z = A68G_TRUE;
       victal_check_formal_pack (NEXT (p), FORMAL_DECLARER_MARK, &z);
       if (!z) {
-        diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
+        diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
       }
       FORWARD (p);
     }
     if (!victal_check_declarer (NEXT (p), FORMAL_DECLARER_MARK)) {
-      diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
+      diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
     }
-    return A68_TRUE;
+    return A68G_TRUE;
   } else {
-    return A68_FALSE;
+    return A68G_FALSE;
   }
 }
 
@@ -281,7 +281,7 @@ BOOL_T victal_check_declarer (NODE_T * p, int x)
 void victal_check_cast (NODE_T * p)
 {
   if (!victal_check_declarer (p, FORMAL_DECLARER_MARK)) {
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_EXPECTED, "formal declarer");
     victal_checker (NEXT (p));
   }
 }
