@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -64,7 +64,7 @@ static size_t a68g_curl_concat (void *data, size_t len, size_t n, void *buf)
   ABEND (((DATA_T *) buf)->ref == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   if (stale != NO_TEXT) {
     MOVE (((DATA_T *) buf)->ref, stale, ((DATA_T *) buf)->len + 1);
-    free (stale);
+    a68g_free (stale);
   }
   MOVE (& (((DATA_T *) buf)->ref[((DATA_T *) buf)->len]), data, new_len);
   ((DATA_T *) buf)->len += new_len;
@@ -117,7 +117,7 @@ void genie_curl_content (NODE_T * p, char *protocol)
     *DEREF (A68G_REF, &content_string) = c_to_a_string (p, data.ref, data.len);
   }
   if (data.ref != NO_TEXT) {
-    free (data.ref);
+    a68g_free (data.ref);
   }
   curl_easy_cleanup (handle);
   curl_global_cleanup ();
