@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -28,7 +28,7 @@
 
 #include "a68g.h"
 
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
 
 #include "a68g-prelude.h"
 #include "a68g-genie.h"
