@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -52,7 +52,7 @@ void restore_stacks (pthread_t);
     if (!((s != NULL) && (BYTES (s) > 0) && (size <= BYTES (s)))) {\
       a68g_free (SWAP (s));\
       SWAP (s) = (BYTE_T *) get_heap_space (size);\
-      ABEND (SWAP (s) == NULL, ERROR_MEMORY_FULL, __func__);\
+      ABEND (SWAP (s) == NULL, ERROR_MEMORY_FULL, NO_TEXT);\
     }\
     START (s) = start;\
     BYTES (s) = size;\
@@ -79,17 +79,17 @@ void restore_stacks (pthread_t);
       (z) = _k_;\
     }\
   }\
-  ABEND ((z) == -1, ERROR_INTERNAL_CONSISTENCY, __func__);\
+  ABEND ((z) == -1, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);\
   }
 
 #define ERROR_THREAD_FAULT "thread fault"
 
 #define LOCK_THREAD {\
-  ABEND (pthread_mutex_lock (&A68G_PAR (unit_sema)) != 0, ERROR_THREAD_FAULT, __func__);\
+  ABEND (pthread_mutex_lock (&A68G_PAR (unit_sema)) != 0, ERROR_THREAD_FAULT, NO_TEXT);\
   }
 
 #define UNLOCK_THREAD {\
-  ABEND (pthread_mutex_unlock (&A68G_PAR (unit_sema)) != 0, ERROR_THREAD_FAULT, __func__);\
+  ABEND (pthread_mutex_unlock (&A68G_PAR (unit_sema)) != 0, ERROR_THREAD_FAULT, NO_TEXT);\
   }
 
 //! @brief Does system stack grow up or down?.
@@ -198,7 +198,7 @@ void restore_stacks (pthread_t t)
     int k;
     GET_THREAD_INDEX (k, t);
 // Restore stack pointers.
-    get_stack_size ();
+    get_C_stack_size ();
     A68G (system_stack_offset) = THREAD_STACK_OFFSET (&(A68G_PAR (context)[k]));
     A68G_FP = CUR_PTR (&FRAME (&(A68G_PAR (context)[k])));
     A68G_SP = CUR_PTR (&STACK (&(A68G_PAR (context)[k])));
@@ -285,7 +285,7 @@ void start_parallel_units (NODE_T * p, pthread_t parent)
         diagnostic (A68G_RUNTIME_ERROR, p, ERROR_THREAD_FAULT);
         exit_genie (p, A68G_RUNTIME_ERROR);
       }
-      ABEND ((size_t) ss != (size_t) A68G (stack_size), ERROR_ACTION, __func__);
+      ABEND ((size_t) ss != (size_t) A68G (stack_size), ERROR_ACTION, NO_TEXT);
       if (pthread_create (&new_id, &new_at, start_unit, NULL) != 0) {
         diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PARALLEL_CANNOT_CREATE);
         exit_genie (p, A68G_RUNTIME_ERROR);
@@ -377,7 +377,7 @@ PROP_T genie_parallel (NODE_T * p)
       diagnostic (A68G_RUNTIME_ERROR, p, ERROR_THREAD_FAULT);
       exit_genie (p, A68G_RUNTIME_ERROR);
     }
-    ABEND ((size_t) ss != (size_t) A68G (stack_size), ERROR_ACTION, __func__);
+    ABEND ((size_t) ss != (size_t) A68G (stack_size), ERROR_ACTION, NO_TEXT);
     if (pthread_create (&A68G_PAR (parent_thread_id), &new_at, start_genie_parallel, NULL) != 0) {
       diagnostic (A68G_RUNTIME_ERROR, p, ERROR_PARALLEL_CANNOT_CREATE);
       exit_genie (p, A68G_RUNTIME_ERROR);
@@ -408,7 +408,7 @@ PROP_T genie_parallel (NODE_T * p)
     A68G_PAR (context_index) = 0;
     A68G_SP = stack_s;
     A68G_FP = frame_s;
-    get_stack_size ();
+    get_C_stack_size ();
     A68G (system_stack_offset) = system_stack_offset_s;
 // See if we ended execution in parallel clause.
     if (is_main_thread () && A68G_PAR (exit_from_threads)) {
