@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2026 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -47,34 +47,34 @@ INT_T a68g_over_int (INT_T, INT_T);
 INT_T a68g_mod_int (INT_T, INT_T);
 REAL_T a68g_div_int (INT_T, INT_T);
 
-void a68g_ln_complex (A68_REAL *, A68_REAL *);
-void a68g_sqrt_complex (A68_REAL *, A68_REAL *);
-void a68g_sin_complex (A68_REAL *, A68_REAL *);
-void a68g_cos_complex (A68_REAL *, A68_REAL *);
-void a68g_tan_complex (A68_REAL *, A68_REAL *);
-void a68g_asin_complex (A68_REAL *, A68_REAL *);
-void a68g_acos_complex (A68_REAL *, A68_REAL *);
-void a68g_atan_complex (A68_REAL *, A68_REAL *);
-void a68g_sinh_complex (A68_REAL *, A68_REAL *);
-void a68g_cosh_complex (A68_REAL *, A68_REAL *);
-void a68g_tanh_complex (A68_REAL *, A68_REAL *);
-void a68g_asinh_real_complex (A68_REAL *, A68_REAL *);
-void a68g_acosh_real_complex (A68_REAL *, A68_REAL *);
-void a68g_atanh_real_complex (A68_REAL *, A68_REAL *);
+void a68g_ln_complex (A68G_REAL *, A68G_REAL *);
+void a68g_sqrt_complex (A68G_REAL *, A68G_REAL *);
+void a68g_sin_complex (A68G_REAL *, A68G_REAL *);
+void a68g_cos_complex (A68G_REAL *, A68G_REAL *);
+void a68g_tan_complex (A68G_REAL *, A68G_REAL *);
+void a68g_asin_complex (A68G_REAL *, A68G_REAL *);
+void a68g_acos_complex (A68G_REAL *, A68G_REAL *);
+void a68g_atan_complex (A68G_REAL *, A68G_REAL *);
+void a68g_sinh_complex (A68G_REAL *, A68G_REAL *);
+void a68g_cosh_complex (A68G_REAL *, A68G_REAL *);
+void a68g_tanh_complex (A68G_REAL *, A68G_REAL *);
+void a68g_asinh_real_complex (A68G_REAL *, A68G_REAL *);
+void a68g_acosh_real_complex (A68G_REAL *, A68G_REAL *);
+void a68g_atanh_real_complex (A68G_REAL *, A68G_REAL *);
 
 // Operators that are inlined in compiled code
 
 #define a68g_eq_complex(x, y) (RE (x) == RE (y) && IM (x) == IM (y))
 #define a68g_ne_complex(x, y) (! a68g_eq_complex (x, y))
-#define a68g_plusab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) += (j), (i))
-#define a68g_min_realusab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) -= (j), (i))
-#define a68g_timesab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) *= (j), (i))
-#define a68g_overab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) /= (j), (i))
+#define a68g_plusab_int(i, j) (VALUE ((A68G_INT *) ADDRESS (i)) += (j), (i))
+#define a68g_min_realusab_int(i, j) (VALUE ((A68G_INT *) ADDRESS (i)) -= (j), (i))
+#define a68g_timesab_int(i, j) (VALUE ((A68G_INT *) ADDRESS (i)) *= (j), (i))
+#define a68g_overab_int(i, j) (VALUE ((A68G_INT *) ADDRESS (i)) /= (j), (i))
 #define a68g_entier(x) ((int) floor (x))
-#define a68g_plusab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) += (j), (i))
-#define a68g_min_realusab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) -= (j), (i))
-#define a68g_timesab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) *= (j), (i))
-#define a68g_divab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) /= (j), (i))
+#define a68g_plusab_real(i, j) (VALUE ((A68G_REAL *) ADDRESS (i)) += (j), (i))
+#define a68g_min_realusab_real(i, j) (VALUE ((A68G_REAL *) ADDRESS (i)) -= (j), (i))
+#define a68g_timesab_real(i, j) (VALUE ((A68G_REAL *) ADDRESS (i)) *= (j), (i))
+#define a68g_divab_real(i, j) (VALUE ((A68G_REAL *) ADDRESS (i)) /= (j), (i))
 #define a68g_re_complex(z) (RE (z))
 #define a68g_im_complex(z) (IM (z))
 #define a68g_abs_real_complex(z) a68g_hypot_real (RE (z), IM (z))
